@@ -15,27 +15,46 @@ test_that("test that stochastic virus app works",
             modelsettings$b = 1e-4
             modelsettings$p = 10
             modelsettings$g = 1
-            modelsettings$tstart = 0
-            modelsettings$tfinal = 100
-            modelsettings$dt = 0.1
 
             modelsettings$rngseed = 100
             modelsettings$tstart = 0
             modelsettings$tfinal = 200
             modelsettings$dt = 0.1
 
-            modelsettings$modeltype = '_ode_and_stochastic_'
             modelsettings$nplots = 1
             modelsettings$nreps = 5
             modelsettings$simfunction = c('simulate_basicvirus_ode', 'simulate_basicvirus_stochastic')
             modelsettings$plotscale = 'y'
 
+            modelsettings$modeltype = '_ode_and_stochastic_'
+            modelsettings$modeltypeUI = '_ode_'
             result = run_model(modelsettings)
 
-            testthat::expect_is( generate_ggplot(result), "ggplot" )
+            p = DSAIRM::generate_ggplot(result)
+            expect_true( is.ggplot(p))
+
             testthat::expect_is( generate_plotly(result), "plotly" )
             testthat::expect_is( generate_text(result), "html" )
             testthat::expect_is( generate_text(result), "character" )
 
+            modelsettings$modeltype = '_ode_and_stochastic_'
+            modelsettings$modeltypeUI = '_stochastic_'
+            result = run_model(modelsettings)
+            p = DSAIRM::generate_ggplot(result)
+            expect_true( is.ggplot(p))
+            testthat::expect_is( generate_plotly(result), "plotly" )
+            testthat::expect_is( generate_text(result), "html" )
+            testthat::expect_is( generate_text(result), "character" )
+
+            modelsettings$modeltype = '_ode_and_stochastic_'
+            modelsettings$modeltypeUI = '_ode_and_stochastic_'
+            result = run_model(modelsettings)
+            p = DSAIRM::generate_ggplot(result)
+            expect_true( is.ggplot(p))
+            testthat::expect_is( generate_plotly(result), "plotly" )
+            testthat::expect_is( generate_text(result), "html" )
+            testthat::expect_is( generate_text(result), "character" )
+
+
             })
 
